##  Creating New Projects
  1. Go to Inventory and click New Fact Sheet in the right hand menu
  2. Select Project as Fact Sheet Type and enter a name for your project
  3. Complete Fact Sheet Information, Dependencies, Project Environment, Project Setup and Project Status
